@@ -492,6 +492,13 @@ gconf_tree_model_init (GConfTreeModel *model)
 	model->client = gconf_client_get_default ();
 }
 
+void
+gconf_tree_model_set_client (GConfTreeModel *model, GConfClient *client)
+{
+	g_object_unref (model->client);
+	model->client = client;
+}
+
 GType
 gconf_tree_model_get_type (void)
 {
